#!/usr/bin/env python
# This scripts read a TMC and a TMT file and extracts the
# the filename and instrument of all the files listed in this file.
# IN this case only for the active instruments + NICMOS. 
# The list of file is output to an aschi file wich has the commands
# to copy the list of files from the centralized storage and put them
# in the indicated directory. For example:
#
#cp /grp/hst/cdbs/comp/acs/acs_f435w_005_syn.fits /grp/hst/cdbs/deliveries/etc/test/comp/acs/.
#
# This file can be sourced to run copy the files to the desired directory
#
# The input parameters are the name of the latest TMC or TMT file,
# the base root directory where we can find the comp/ directory
# and the name of the output file. For example:
#
# python ../scripts/tmc_tmt_delivery.py /grp/hst/cdbs/mtab/v9n1603lm_tmc.fits cdbs.20.1rc1 cdbs.20.1rc1_tmc.out
#

import sys
import pyfits

def run(tmcname,buildid,fileout):
    dircdbs = '/grp/hst/cdbs/comp/'
    dirdelivery = '/grp/hst/cdbs/deliveries/etc/'
    instrument = ' '
    f=pyfits.open(tmcname)
    print tmcname
    fnames=f[1].data.field('filename')
    f.close()

    # List of files to copy to deliver to ETC
    cpfiles = open(fileout,'w')
    for fn in fnames:
       d1 = ' '
       nn = 0
       if fn[0:9] == 'crotacomp' :
          nn=10
          instrument = 'ota'
       if fn[0:10] == 'crstiscomp' :
          nn=11
          instrument = 'stis'
       elif fn[0:9] == 'cracscomp':
          nn=10
          instrument = 'acs'
       elif fn[0:9] == 'crcoscomp':
          nn=10
          instrument = 'cos'
       elif fn[0:10] == 'crwfc3comp':
          nn=11
          instrument = 'wfc3'
       elif fn[0:12] == 'crnonhstcomp':
          nn=13
          instrument = 'nonhst'
       elif fn[0:12] == 'crnicmoscomp':
          nn=13
          instrument = 'nicmos'

       if nn != 0:
          d1 = dircdbs + instrument + '/'

       if d1 != ' ':
          d1 = dircdbs + instrument + '/'
          d2 = dirdelivery + buildid + '/comp/' + instrument + '/'
          s1 = str.find(fn,'[')
          if s1 != -1:
             cpfiles.write('cp ' + d1 + fn[nn:s1] + ' ' + d2 + '.\n')
          else:
             cpfiles.write('cp ' + d1 + fn[nn:] + ' ' + d2 + '.\n')
    cpfiles.close()

if __name__ == '__main__':
    run(sys.argv[1],sys.argv[2],sys.argv[3])

